function Figure10(soundingdata_path,HOLIMOdata_path)
% HOLIMOdata_path='/holimo/6_Auswertung/Julie/NYA/FINAL_DATA/netcdf_t30/';
% soundingdata_path='/holimo/6_Auswertung/Julie/NYA/ACP_SIP/Data/Radiosonde/';

%Values to change depending on wishes
ice_small = 110e-6;
height=50;
dropletslim=0.005;
rhilim=95;
time_resolution='30';
data_str={'191108_2';'191109_1';'191109_2';'191110_1';'191110_2';'191111_1';'191111_2';'191112_1';'191112_2';'191112_3';'200401_1'};


%Prepare empty arrays for loop
N_icesmall_all=[];
Volumetot=0;

%Loop over all the data in the function
for j=1:11
    
    holodata=readHoloBalloon([HOLIMOdata_path data_str{j} '_t' time_resolution '.nc']);     
    
    %Get balloon time and height
    balloon_time = holodata.time;
    balloon_height = holodata.instData_height;
      
    
    %Ice selection and putting together classes
    binSize = holodata.diameter;
    binWidth = holodata.diameterLogBinWidth;
    PSDlogNorm = zeros(size(holodata.Ice_PSDlogNormMajsiz));
    
    %Smass ice crystals used for SIP detection are selected fro the ice
    %categories 'Column','Plates', and 'Small' ice
    if isfield(holodata,'Ice_Column_concentration')
        PSDlogNorm =PSDlogNorm+holodata.Ice_Column_PSDlogNormMajsiz;
    end
    if isfield(holodata,'Ice_Plate_concentration')
        PSDlogNorm =PSDlogNorm+ holodata.Ice_Plate_PSDlogNormMajsiz;
    end
    if isfield(holodata, 'Ice_Small_concentration')
        PSDlogNorm =PSDlogNorm+holodata.Ice_Small_PSDlogNormMajsiz;
    end
    
    %Selection of small ice particles 
    idx_small = max(find(binSize<=ice_small));
    N_ice = PSDlogNorm.*binWidth';
    N_ice_small = nansum(N_ice(:,1:idx_small),2);

    %Read radiosonde data
    datesounding=datestr(holodata.instData_timeGPS(1), 'YYYYmmDD');
    output=interpolate_radiosondes(soundingdata_path,datesounding,4000);
    radiosond_z=output.alt;
    radiosond_t=output.time;
    radiosond_T=output.temp_inter_heighttime;
    radiosond_RH=output.RH_inter_heighttime;
    
    %Determine temperature and RH at HoloBalloon location
    balloon_temp=NaN(length(balloon_time),1);
    balloon_RH=NaN(length(balloon_time),1);
        for i=1:length(balloon_height)
        [~,alt_id]=min(abs(balloon_height(i)-radiosond_z));
        [~,time_id]=min(abs(balloon_time(i)-radiosond_t));
        balloon_temp(i)=radiosond_T(alt_id,time_id)-273.15;
        balloon_RH(i)=radiosond_RH(alt_id,time_id);
        end
    
    %Calculate saturation with respect to ice
    esw=2.53*10e11*exp(-5420./(balloon_temp+273.15));
    esi=3.64*10e12*exp(-6148./(balloon_temp+273.15));
    balloon_RHi=balloon_RH.*esw./esi;    
    
    %remove data at ground and or not in cloud
    idz=find(holodata.Water_content>dropletslim | balloon_RHi>rhilim & balloon_height >=height);
        
    %Add data in loop over several flights
    N_icesmall_all=[N_icesmall_all N_ice_small(idz)'];
   Volumetot=Volumetot+sum(holodata.Ice_volume(idz)');   
end


%Calculate percentage of the time with SIP
noSIP=0;
lowSIP=1;
highSIP=10;

SIPlow_id=find(N_icesmall_all.*1e3>noSIP & N_icesmall_all.*1e3<=lowSIP);
percentSIPlow=length(SIPlow_id)/length(N_icesmall_all)*100;

SIPmiddle_id=find(N_icesmall_all.*1e3>lowSIP & N_icesmall_all.*1e3<=highSIP);
percentSIPmiddle=length(SIPmiddle_id)/length(N_icesmall_all)*100;

SIPhigh_id=find(N_icesmall_all.*1e3>highSIP);
SIPhigh=sum(N_icesmall_all.*1e3>=highSIP)/length(N_icesmall_all)*100;

SIPno_id=find(N_icesmall_all.*1e3==noSIP);
SIP_no=sum(N_icesmall_all==noSIP)/length(N_icesmall_all)*100;


SIPhigh=round(SIPhigh*2)/2;

SIPfreq=[SIPhigh percentSIPmiddle percentSIPlow    SIP_no];
SIPnumber=[length(SIPhigh_id) length(SIPmiddle_id) length(SIPlow_id) length(SIPno_id)];
labels={'SIP_{high}', 'SIP_{mod}','SIP_{low}', 'SIP_{no}'};

percent=SIPfreq(:)./sum(SIPfreq(:))*100;
label = cellstr(num2str( percent, '%.1f%%'));  
labelling = cellstr(num2str(SIPnumber', '%d '));


%plot
fig=figure(1);
fig.Units = 'centimeters';
fig.Position = [0 1 20.8 20.5];
fig.PaperPositionMode = 'auto';
p1=pie(SIPfreq,labelling);
T=p1(strcmpi(get(p1,'Type'),'text'));
P=cell2mat(get(T,'Position'));
set(T,{'Position'},num2cell(P*0.7,2))
text(P(:,1),P(:,2),label(:),'FontSize',20)
t = p1(2:2:end); 
p = p1(1:2:end);
t(1).FontSize=25;
t(2).FontSize=25;
t(3).FontSize=25;
t(4).FontSize=25;
p(1).FaceAlpha=0.3;
p(2).FaceAlpha=0.3;
p(3).FaceAlpha=0.3;
colormap([1 0. 0.;      
          0.3 1 0.1;
          0.1 0.35 0.8;
          0 0 0])
lgd = legend(labels);
lgd.FontSize=30;
end
