
function Figure11(soundingdata_path,HOLIMOdata_path)
%HOLIMOdata_path -> path to all HOLIMO data in 30sec resolution
% soundingdata_path -> path to all radiosonde data


%Values to change depending on wishes
FS=27;
droplet_large = 65e-6;
ice_small = 110e-6;
ice_large=300e-6;
height=50;
dropletslim=0.005;
rhilim=95;


%Prepare empty arrays for loop
N_timesteps=0;
Ndropletlarge_all=[];
Ndropletfrozen_all=[];
radiosondes_all=[];
N_icesmall_all=[];
N_icelarge_all=[];
Ndropletsmall_all=[];
time_resolution='30';
data_str={'191108_2';'191109_1';'191109_2';'191110_1';'191110_2';'191111_1';'191111_2';'191112_1';'191112_2';'191112_3';'200401_1'};
N_flight=NaN(length(data_str),1);


N_timeflightstart=0;
%Loop over all the flights data
for j=1:length(data_str)
    holodata=readHoloBalloon([HOLIMOdata_path data_str{j} '_t' time_resolution '.nc']);              
    
    %Get balloon time and height
    balloon_time = holodata.time;
    balloon_height = holodata.instData_height;
      
    
    %Ice selection and putting together classes
    binSize = holodata.diameter;
    binWidth = holodata.diameterLogBinWidth;
    PSDlogNorm = zeros(size(holodata.Ice_PSDlogNormMajsiz));
    
    %Smass ice crystals used for SIP detection are selected fro the ice
    %categories 'Column','Plates', and 'Small' ice
    if isfield(holodata,'Ice_Column_concentration')
        PSDlogNorm =PSDlogNorm+holodata.Ice_Column_PSDlogNormMajsiz;
    end
    if isfield(holodata,'Ice_Plate_concentration')
        PSDlogNorm =PSDlogNorm+ holodata.Ice_Plate_PSDlogNormMajsiz;
    end
    if isfield(holodata, 'Ice_Small_concentration')
        PSDlogNorm =PSDlogNorm+holodata.Ice_Small_PSDlogNormMajsiz;
    end
    
    %Selection of small ice particles 
    idx_small = max(find(binSize<=ice_small));
    N_ice = PSDlogNorm.*binWidth';
    N_ice_small = nansum(N_ice(:,1:idx_small),2);
    
    
    %Selection of large ice particles
    idx_large= min(find(binSize>=ice_large));
    N_ice_tot=holodata.Ice_PSDlogNormMajsiz.*binWidth';
    N_ice_large = nansum(N_ice_tot(:,idx_large:end),2);
    
    
    %Water selection small vs large droplets
    droplet_PSDlogNorm = holodata.Water_PSDlogNormMajsiz;
    idx_droplet_large = max(find(binSize<=droplet_large));
    N_droplet = droplet_PSDlogNorm.*binWidth';
    N_droplet_large = nansum(N_droplet(:,idx_droplet_large:end),2);
    N_droplet_small = nansum(N_droplet(:,1:idx_droplet_large-1),2);
    
    %Selection frozen droplets
    N_dfrozen=[];
    if isfield(holodata,'Ice_Droplet_frozen_concentration')
        N_dfrozen=holodata.Ice_Droplet_frozen_concentration;
    else
        N_dfrozen=zeros(length(holodata.Ice_concentration),1);
    end
   
    
    %Read radiosonde data
    datesounding=datestr(holodata.instData_timeGPS(1), 'YYYYmmDD');
    output=interpolate_radiosondes(soundingdata_path,datesounding,4000);
    radiosond_z=output.alt;
    radiosond_t=output.time;
    radiosond_T=output.temp_inter_heighttime;
    radiosond_RH=output.RH_inter_heighttime;
    
    %Determine temperature and RH at HoloBalloon location
    balloon_temp=NaN(length(balloon_time),1);
    balloon_RH=NaN(length(balloon_time),1);
        for i=1:length(balloon_height)
        [~,alt_id]=min(abs(balloon_height(i)-radiosond_z));
        [~,time_id]=min(abs(balloon_time(i)-radiosond_t));
        balloon_temp(i)=radiosond_T(alt_id,time_id)-273.15;
        balloon_RH(i)=radiosond_RH(alt_id,time_id);
        end
    
    %Calculate saturation with respect to ice
    esw=2.53*10e11*exp(-5420./(balloon_temp+273.15));
    esi=3.64*10e12*exp(-6148./(balloon_temp+273.15));
    balloon_RHi=balloon_RH.*esw./esi;
    
    
    %remove data at ground and or not in cloud
    idz=find(holodata.Water_content>dropletslim | balloon_RHi>rhilim & balloon_height >=height);
    
    
    %Add data in loop over several flights
    N_timesteps=N_timesteps+length(idz);
    N_flight(j)=length(idz);
    N_timeflightstart(j+1)=N_timeflightstart(j) + length(idz);
    Ndropletfrozen_all=[Ndropletfrozen_all N_dfrozen(idz)'];
    Ndropletsmall_all=[Ndropletsmall_all N_droplet_small(idz)'];
    Ndropletlarge_all=[Ndropletlarge_all N_droplet_large(idz)'];
    radiosondes_all=[radiosondes_all balloon_temp(idz)'];
    N_icesmall_all=[N_icesmall_all N_ice_small(idz)'];
    N_icelarge_all=[N_icelarge_all N_ice_large(idz)'];
    
end


%Add space between the filghts for plotting
N_timeflightstart(1)=1;
addnan=[0;1;2;3;4;5;6;7;8;9;10];
timesteps=[1:N_timesteps+100];


%Plot
fig=figure(2);
fig.Units = 'centimeters';
fig.Position = [0 1 48 60];
fig.PaperPositionMode = 'auto';
sp1=subplot(5,1,1);
for p=1:length(N_timeflightstart)-1
    l=addnan(p);
    plot(timesteps((N_timeflightstart(p)+l*10+1):(N_timeflightstart(p+1)+l*10)),N_icesmall_all(N_timeflightstart(p)+1:N_timeflightstart(p+1)).*1e3 ,'LineWidth', 1.52, 'color',[0.8 0.08 0.1])
    hold on
end
ylabel(['ICNC_{pr<106 ' char(181) 'm} (L^{-1})'])
hold on
ylim([-1 200])
xlim([1 N_timeflightstart(end)])
set(gca,'XTick','')
for q=2:length(N_timeflightstart)-1
    l=addnan(q);
    text(N_timeflightstart(q)+l*10-12, 0.3,'//','Color', 'k','FontSize',12,'FontWeight', 'bold')
end
plot([1 timesteps(end)], [1 1], '--', 'color', 'k', 'LineWidth', 0.5)
plot([1 timesteps(end)], [10 10], '--', 'color', 'k', 'LineWidth', 0.4)
set(gca,'Fontsize',FS);
set(gca,'YScale','log')
set(gca, 'YTick', [1  10^2 ])
set(gca,'YMinorTick','on')
ylim([0.3 200])

sp2=subplot(5,1,2);
for p=1:length(N_timeflightstart)-1
    l=addnan(p);
    plot(timesteps((N_timeflightstart(p)+l*10+1):(N_timeflightstart(p+1)+l*10)),Ndropletsmall_all(N_timeflightstart(p)+1:N_timeflightstart(p+1)),'LineWidth', 1.52, 'color',[0.9290 0.6940 0.1250])
    hold on
    plot(timesteps((N_timeflightstart(p)+l*10+1):(N_timeflightstart(p+1)+l*10)),Ndropletlarge_all(N_timeflightstart(p)+1:N_timeflightstart(p+1)).*1e3,'LineWidth',1.52, 'color',[0.8500 0.3250 0.0980] )
end
for q=2:length(N_timeflightstart)-1
    l=addnan(q);
    text(N_timeflightstart(q)+l*10-12, 0,'//','Color', 'k','FontSize',12,'FontWeight', 'bold')
end
ylabel('CDNC (cm^{-3})')
l2=legend(['CDNC'], ['SLDNC x10^{3}']);
l2.Location='northeast';
xlim([1 N_timeflightstart(end)])
set(gca,'XTick','')
for q=2:length(N_timeflightstart)-1
    l=addnan(q);
    text(N_timeflightstart(q)+l*10-12, 0.1,'//','Color', 'k','FontSize',12,'FontWeight', 'bold')
end
set(gca,'Fontsize',FS);
set(gca,'YScale','log')
set(gca, 'YTick', [1  10^2 10^4 ])
set(gca,'YMinorTick','on')
ylim([0.1 10000])


sp3=subplot(5,1,3);
for p=1:length(N_timeflightstart)-1
    l=addnan(p);
    plot(timesteps((N_timeflightstart(p)+l*10+1):(N_timeflightstart(p+1)+l*10)),Ndropletfrozen_all(N_timeflightstart(p)+1:N_timeflightstart(p+1)).*1e3,'LineWidth', 1.52,'color',[0.3660 0.5740 0.0880] )
    hold on
end
ylabel({'Frozen drops' ; 'concentration (L^{-1})'})
xlim([1 N_timeflightstart(end)])
set(gca,'XTick','')
for q=2:length(N_timeflightstart)-1
    l=addnan(q);
    text(N_timeflightstart(q)+l*10-12, 0.3,'//','Color', 'k','FontSize',12,'FontWeight', 'bold')
end
set(gca,'Fontsize',FS);
set(gca,'YScale','log')
ylim([0.3 20])


sp4=subplot(5,1,4);
for p=1:length(N_timeflightstart)-1
    l=addnan(p);
    p1=plot(timesteps((N_timeflightstart(p)+l*10+1):(N_timeflightstart(p+1)+l*10)),N_icelarge_all(N_timeflightstart(p)+1:N_timeflightstart(p+1)).*1e3,'LineWidth', 1.52, 'color',[0.4940 0.1840 0.5560]);
    hold on    
end
ylabel({'Snow crystal' ; 'concentration (L^{-1})'})
plot([1 timesteps(end)], [1 1], '--', 'color', 'k', 'LineWidth', 0.5)
plot([1 timesteps(end)], [10 10], '--', 'color', 'k', 'LineWidth', 0.4)

xlim([1 N_timeflightstart(end)])
set(gca,'XTick','')
for q=2:length(N_timeflightstart)-1
    l=addnan(q);
    text(N_timeflightstart(q)+l*10-12, 0.3,'//','Color', 'k','FontSize',12,'FontWeight', 'bold')
end
set(gca,'Fontsize',FS);
set(gca,'YScale','log')
set(gca, 'YTick', [1  10^2 ])
set(gca,'YMinorTick','on')
ylim([0.3 200])




sp5=subplot(5,1,5);
for p=1:length(N_timeflightstart)-1
    l=addnan(p);
    plot(timesteps((N_timeflightstart(p)+l*10+1):(N_timeflightstart(p+1)+l*10)),radiosondes_all(N_timeflightstart(p)+1:N_timeflightstart(p+1)),'LineWidth', 1.52, 'color','k' )
    hold on
end
xlim([1 N_timeflightstart(end)])
for q=2:length(N_timeflightstart)-1
    l=addnan(q);
    text(N_timeflightstart(q)+l*10-12, -25,'//','Color', 'k','FontSize',12,'FontWeight', 'bold')
end
for xt=1:length(N_timeflightstart)-1
    l=addnan(xt);
    ticks(xt)=(N_timeflightstart(xt+1)-N_timeflightstart(xt))/2+N_timeflightstart(xt)+l*10-12;
end
set(gca,'XTick',ticks)
set(gca,'TickLength',[0,0])
ylim([-25 0])
ylabel('Temperature (°C)')
set(gca,'Fontsize',FS)
set(gca,'XTick',ticks)
ticklabel={'2019/11/08 #1'; '2019/11/09 #1'; '2019/11/09 #2'; '2019/11/10 #1'; '2019/11/10 #2'; '2019/11/11 #1'; '2019/11/11 #2'; '2019/11/12 #1'; '2019/11/12 #2'; '2019/11/12 #3'; '2020/04/01 #1'};
set(gca,'XTickLabel',ticklabel)
set(gca,'Fontsize',FS);
xtickangle(45)

sp1.Position=[0.100    0.79    0.85    0.14];
sp2.Position=[0.100    0.62    0.85    0.14];
sp3.Position=[0.100    0.45    0.85   0.14];
sp4.Position=[0.100    0.28    0.85    0.14];
sp5.Position=[0.100    0.11    0.85    0.14];

end