
function Figure12(soundingdata_path,HOLIMOdata_path)
%HOLIMOdata_path -> path to all HOLIMO data in 30sec resolution
%soundingdata_path -> path to all radiosonde data


%Values to change depending on wishes
FS=24;
ice_small = 110e-6;
height=50;
dropletslim=0.005;
rhilim=95;
time_resolution='30';
data_str={'191108_2';'191109_1';'191109_2';'191110_1';'191110_2';'191111_1';'191111_2';'191112_1';'191112_2';'191112_3';'200401_1'};


%Prepare empty arrays for loop
radiosondes_all=[];
N_icesmall_all=[];
N_iceconc_all=[];

N_timeflightstart=0;
%Loop over all the data in the function
for j=1:11
    holodata=readHoloBalloon([HOLIMOdata_path data_str{j} '_t' time_resolution '.nc']);     
        
    
    %Get balloon time and height
    balloon_time = holodata.instData_timeGPS;
    balloon_height = holodata.instData_height;
      
    
    %Ice selection and putting together classes
    binSize = holodata.diameter;
    binWidth = holodata.diameterLogBinWidth;
    PSDlogNorm = zeros(size(holodata.Ice_PSDlogNormMajsiz));
    
    %Smass ice crystals used for SIP detection are selected fro the ice
    %categories 'Column','Plates', and 'Small' ice
    if isfield(holodata,'Ice_Column_concentration')
        PSDlogNorm =PSDlogNorm+holodata.Ice_Column_PSDlogNormMajsiz;
    end
    if isfield(holodata,'Ice_Plate_concentration')
        PSDlogNorm =PSDlogNorm+ holodata.Ice_Plate_PSDlogNormMajsiz;
    end
    if isfield(holodata, 'Ice_Small_concentration')
        PSDlogNorm =PSDlogNorm+holodata.Ice_Small_PSDlogNormMajsiz;
    end
    
    %Selection of small ice particles 
    idx_small = max(find(binSize<=ice_small));
    N_ice = PSDlogNorm.*binWidth';
    N_ice_small = nansum(N_ice(:,1:idx_small),2);
    
    
    %Selection of all ice particles
    N_iceconc=holodata.Ice_concentration;     
    
    
    %Read radiosonde data
    datesounding=datestr(holodata.instData_timeGPS(1), 'YYYYmmDD');
    output=interpolate_radiosondes(soundingdata_path,datesounding,4000);
 
    radiosond_z=output.alt;
    radiosond_t=output.time;
    radiosond_T=output.temp_inter_heighttime;
    radiosond_RH=output.RH_inter_heighttime;
    balloon_temp=NaN(length(balloon_time),1);
    balloon_RH=NaN(length(balloon_time),1);
    for i=1:length(balloon_height)
        [~,alt_id]=min(abs(balloon_height(i)-radiosond_z));
        [~,time_id]=min(abs(balloon_time(i)-radiosond_t)); 
        balloon_temp(i)=radiosond_T(alt_id,time_id)-273.15;
        balloon_RH(i)=radiosond_RH(alt_id,time_id);
    end
       
    esw=2.53*10e11*exp(-5420./(balloon_temp+273.15));
    esi=3.64*10e12*exp(-6148./(balloon_temp+273.15));
    balloon_RHi=balloon_RH.*esw./esi;
     
    
     %remove data at ground and not in cloud
    idz=find(holodata.Water_content>dropletslim | balloon_RHi>rhilim & balloon_height >=height);
        
    
    N_timeflightstart(j+1)=N_timeflightstart(j) + length(idz);
    radiosondes_all=[radiosondes_all balloon_temp(idz)'];
    N_icesmall_all=[N_icesmall_all N_ice_small(idz)'];
    N_iceconc_all=[N_iceconc_all N_iceconc(idz)'];
    
end




%Percentage of the time with SIP
noSIP=0;
SIPall_id=find(N_icesmall_all.*1e3>noSIP);
SIPno_id=find(N_icesmall_all.*1e3==noSIP);


N_icesmall_all1=N_icesmall_all(SIPall_id);
radiosondes_all1=radiosondes_all(SIPall_id);
N_ice_all1=N_iceconc_all(SIPall_id);


binst=[-24:1:0];
bins1=10.^[-3.2:0.13:-0.95];
%bins=[0.00031 0.00044 bins1];
bins=[bins1];

[TempSIPcount1,ii] = histc(radiosondes_all1, binst);
TempSIPcount=[TempSIPcount1(1) TempSIPcount1];
Tempbins=binst(ii)';


N_icezero=N_icesmall_all(SIPno_id);
N_tempzero=radiosondes_all(SIPno_id);
N_ice_allzero=N_iceconc_all(SIPno_id);

[Tempzerocount1,kk] = histc(N_tempzero, binst);
Tempbins0=binst(kk)';
Tempzerocount=[Tempzerocount1(1) Tempzerocount1];



matrixtempNice_all=[];
matrixtempNice_all0=[];
maxicesmalltemp=NaN(length(binst),1);
for w=1:length(binst)
    idtemp=find(Tempbins(:)==binst(w));
    idtemp0=find(Tempbins0(:)==binst(w));
    icesmall=N_icesmall_all1(idtemp)'; 
    alliceSIP=N_ice_all1(idtemp); %all ice when SIP
    allicenoSIP=N_ice_allzero(idtemp0); %all ice when no SIP
    [q,mm]=histc(icesmall,bins);
    for d=1:length(bins)
        binsum(d)=sum(icesmall(mm(:)==d));

    end
    p=length(idtemp0);
    pnew=p*0.0003/(nansum(alliceSIP)+nansum(allicenoSIP)+p*0.0003);    
    qnew=binsum'/(nansum(alliceSIP)+nansum(allicenoSIP)+p*0.0003); 
    if ~isempty(icesmall) 
    maxicesmalltemp(w)=max(icesmall);
    else 
        maxicesmalltemp(w)=0;
    end
    if length(q(:,1)) ~=length(bins)
        matrixtempNice_all=[matrixtempNice_all; qnew];        
    else
        matrixtempNice_all=[matrixtempNice_all; qnew'];
    end
    matrixtempNice_all0=[matrixtempNice_all0; pnew'];
end

matrixtempNice_all(isnan(matrixtempNice_all))=0;
matrixtempNice_all0(isnan(matrixtempNice_all0))=0;


[icecounttot,~]=histc(N_icesmall_all,bins);

tempcounts_allflight=zeros(length(N_timeflightstart)-1,length(binst)+1);
icecounts_allflight=zeros(length(N_timeflightstart)-1,length(bins));

for p=1:length(N_timeflightstart)-1
[tempcount_flight,~]=histc(radiosondes_all(N_timeflightstart(p)+1:N_timeflightstart(p+1)),binst);
tempcounts_allflight(p,:)=[tempcount_flight(1) tempcount_flight];
[Nicecount_flight,~]=histc(N_icesmall_all(N_timeflightstart(p)+1:N_timeflightstart(p+1)),bins);
icecounts_allflight(p,:)=[Nicecount_flight];
end

tempcounts_allflight_mergeddays=zeros(6,length(binst)+1);
tempcounts_allflight_mergeddays(1,:)=tempcounts_allflight(1,:);
tempcounts_allflight_mergeddays(2,:)=tempcounts_allflight(2,:)+tempcounts_allflight(3,:);
tempcounts_allflight_mergeddays(3,:)=tempcounts_allflight(4,:)+tempcounts_allflight(5,:);
tempcounts_allflight_mergeddays(4,:)=tempcounts_allflight(6,:)+tempcounts_allflight(7,:);
tempcounts_allflight_mergeddays(5,:)=tempcounts_allflight(8,:)+tempcounts_allflight(9,:)+tempcounts_allflight(10,:);
tempcounts_allflight_mergeddays(6,:)=tempcounts_allflight(11,:);

icecounts_allflight_mergeddays=zeros(6,length(bins));
icecounts_allflight_mergeddays(1,:)=icecounts_allflight(1,:);
icecounts_allflight_mergeddays(2,:)=icecounts_allflight(2,:)+icecounts_allflight(3,:);
icecounts_allflight_mergeddays(3,:)=icecounts_allflight(4,:)+icecounts_allflight(5,:);
icecounts_allflight_mergeddays(4,:)=icecounts_allflight(6,:)+icecounts_allflight(7,:);
icecounts_allflight_mergeddays(5,:)=icecounts_allflight(8,:)+icecounts_allflight(9,:)+icecounts_allflight(10,:);
icecounts_allflight_mergeddays(6,:)=icecounts_allflight(11,:);


%Plot Figure 12
fig=figure(1);
fig.Units = 'centimeters';
fig.Position = [0 1 55.8 30.5];
fig.PaperPositionMode = 'auto';

sp1 = subplot(2,4,1);
stairs([0;0.005; 0.01],[length(N_icezero) length(N_icezero) 0], 'k', 'LineWidth',3)
hold on
set(gca,'XTick','')
set(gca,'YScale','log')
set(gca,'Fontsize',FS);
xlim([0 0.01])
set(gca,'YTick',[5 100 1000])
set(gca,'TickLength',[0.02 0.04],'TickDir','out');
ylabel('N_{Meas} (#)')
ylim([1 2000])
box on
sp1.Position=[0.18    0.7    0.02    0.15];


sp2 = subplot(2,4,2);
stairs(bins.*1e3,icecounttot, 'Color','k', 'LineWidth',2)
hold on
 for p=1:length(tempcounts_allflight_mergeddays(:,1))
 stairs(bins.*1e3,icecounts_allflight_mergeddays(p,:),  'LineWidth',2)
 hold on
 end
stairs(bins.*1e3,icecounttot, 'Color','k', 'LineWidth',3)

hold on
set(gca,'XTick','')
ylim([1 2000])
set(gca,'YScale','log')
set(gca,'XScale','log')
set(gca,'Fontsize',FS);
xlim([0.55 100])
set(gca,'YTick','')
box on
set(gca, 'Layer', 'top')
sp2.Position=[0.2    0.7    0.5    0.15];

sp3 = subplot(2,4,5);
surface([0;0.01]',binst,[matrixtempNice_all0 matrixtempNice_all0], 'EdgeColor','none')
ylabel('Temperature (°C)')
caxis([0.001 1])
cbar=colorbar('Location','westoutside');
cbar.Label.String = {['ICNC_{pr<106 ' char(181) 'm} / total ICNC']};
cbar.Label.FontSize = FS;
cbar.Ticks = [0.001 0.01 0.1 1];
cbar.TickLabels={'0.001';'0.01';'0.1';'1'};
turbo;
set(gca,'ColorScale','log')
cmap = turbomap(1:end,:);
cmap(1,:)=[1 1 1];
colormap(cmap);
set(gca,'Fontsize',FS);
set(gca,'XTick',0.005)
set(gca,'XTickLabel','< 0.3')
set(gca,'TickLength',[0.04 0.04],'TickDir','out');
box on
sp3.Position=[0.18    0.15    0.02    0.5];
cbar.Position(1) =cbar.Position(1)- 0.02;
cbar.Position(3) =3* cbar.Position(3) ;


sp6 = subplot(2,4,8);
sp6.Position=[0.87    0.15    0.1    0.5];
SIPbar=[TempSIPcount' Tempzerocount'];
bs=barh(SIPbar, 'stacked');
bs(1).FaceColor=[0.8 0.08 0.1];
bs(2).FaceColor=[0 0 0];
set(gca,'YTick','')
ylim([0 25])
xlim([0 400])
set(gca,'Fontsize',FS);
box on
xlabel('N_{Meas} (#)')
legend([bs(2) bs(1)], 'SIP_{no}', 'SIP_{all}', 'Location', 'northoutside');



sp5 = subplot(2,5,7);
sp5.Position=[0.74    0.15    0.1    0.5];
bsf=barh(tempcounts_allflight_mergeddays', 'stacked');
set(gca,'YTick','')
ylim([0 25])
xlim([0 400])
set(gca,'Fontsize',FS);
box on
xlabel('N_{Meas} (#)')
leg=legend('2019/11/08', '2019/11/09','2019/11/10', '2019/11/11', '2019/11/12','2020/04/01', 'Location', 'northoutside');
leg.ItemTokenSize = [10,20];



sp4 = subplot(2,4,6);
surface(bins.*1e3,binst,matrixtempNice_all, 'EdgeColor','none')
hold on
set(gca,'XScale','log')
xlabel(['ICNC_{pr<106 ' char(181) 'm} (L^{-1})'])
caxis([0.001 1])
turbo;
set(gca,'ColorScale','log')
cmap = turbomap(1:end,:);
cmap(1,:)=[1 1 1];
colormap(cmap);
set(gca,'Fontsize',FS);
xlim([0.55 100])%0.25
set(gca,'YTick','')
set(gca,'TickLength',[0.02 0.04],'TickDir','out');
set(gca,'XTick',[0.5  1 10 100])
box on
set(gca, 'Layer', 'top')
sp4.Position=[0.2    0.15    0.5    0.5];
end
