function Figure3(weatherdata_path,cloudradardata_path,inpdata_path,windlidardata_path,soundingdata_path,HOLIMOdata_path,HOLIMOlogdata_path)
% inpdata_path -> path to all INP data
% windlidardata_path -> path to all wind lidar data
% cloudradardata_path -> path to all cloud radar data 
% HOLIMOdata_path -> path to all HoloBalloon data (with time resolution t300)
% HOLIMOlogdata_path -> path to all HoloBalloon log data
% soundingdata_path -> path to all radiosonde data

%variables used throughout manuscript
strtdate='20191108';
enddate='20191113';
time_resolution='300';
data_str={'191108_2';'191109_1';'191109_2';'191110_1';'191110_2';'191111_1';'191111_2';'191112_1';'191112_2';'191112_3';'200401_1'};
height_lim=3000;
FS = 27;
LW = 1.5;
droplet_large = 65e-6;
droplet_small=40e-6;
ice_small = 110e-6;
rhlim=90;
dropletslim=0.05;
speed_lims.min = 0;
speed_lims.max = 20;
width_barbs =0.2;
windline=1;


%Define date to plot
startDate = dtstr2dtnummx(cellstr(strtdate),'yyyyMMdd');
endDate = dtstr2dtnummx(cellstr(enddate),'yyyyMMdd');
startDatefeed=dtstr2dtnummx(cellstr('20200401'),'yyyyMMdd');
endDatefeed=dtstr2dtnummx(cellstr('20200402'),'yyyyMMdd');
days_length=str2double(enddate)-str2double(strtdate);
for u=1:days_length
    days{u}=num2str(str2double(strtdate)+u-1);
end
days{u+1}='20200401';



%Read INP data
INP=ncread([inpdata_path 'NYA2019_DRINCZ_INP.nc'], 'INP');
INP_Temp=ncread([inpdata_path 'NYA2019_DRINCZ_INP.nc'], 'T');
INP_time=h5read([inpdata_path 'NYA2019_DRINCZ_INP.nc'], '/time');
INP_type=h5read([inpdata_path 'NYA2019_DRINCZ_INP.nc'], '/type');
INP_aero=strcmp(INP_type,'Aero');
INP=INP(:,INP_aero);
INP_time=INP_time(INP_aero);
INP_t=datenum(INP_time, 'yyyy-mm-dd HH:MM:SS');

INP2=ncread([inpdata_path 'NYA2020_DRINCZ_INP.nc'], 'INP');
INP_Temp2=ncread([inpdata_path 'NYA2020_DRINCZ_INP.nc'], 'T');
INP_time2=h5read([inpdata_path 'NYA2020_DRINCZ_INP.nc'], '/time');
INP_type2=h5read([inpdata_path 'NYA2020_DRINCZ_INP.nc'], '/type');

INP_aero2=strcmp(INP_type2,'Aero');
INP2=INP2(:,INP_aero2);
INP_time2=INP_time2(INP_aero2);
INP_t2=datenum(INP_time2, 'yyyy-mm-dd HH:MM:SS');



%Read weather station data
weather=read_weatherdata(weatherdata_path,'20200401000000','20200402025900');
weather1=read_weatherdata(weatherdata_path,'20200331210000','20200331235959');
weather3=read_weatherdata(weatherdata_path,'20191108000000','20191113000000');

%movmean over the weather station data 
weather.Temp2=movmean(weather.Temp2,15);
weather1.Temp2=movmean(weather1.Temp2,15);
weather.pressure=movmean(weather.pressure,15);
weather1.pressure=movmean(weather1.pressure,15);
weather1.Wspeed2=movmean(weather1.Wspeed2,15);
weather.Wspeed2=movmean(weather.Wspeed2,15);
weather1.Wdir2=movmean(weather1.Wdir2,15);
weather.Wdir2=movmean(weather.Wdir2,15);
weather3.Temp2=movmean(weather3.Temp2,15);
weather3.pressure=movmean(weather3.pressure,15);
weather3.Wspeed2=movmean(weather3.Wspeed2,15);
weather3.Wdir2=movmean(weather3.Wdir2,15);


%preallocate for loop over all days
radar_height=[];
radar_timetot=[];
Z_tot=[];
radiosond_time_all=[];
cloudtopalt_all= [];
cloudtoptemp_all=[];
INP_tempcloudtop_all=[];
INP_t_all=[];
INP_balloon_dt_all=[];
INP_tempballoon_all=[];
z_mean_all=[];
t_mean_all=[];
station_altitude_nyalesund=0;
winds_u_all=[];
winds_v_all=[];

%loop over all days to retrieve the cloud radar, the wind profiler, the
%radiosonde data
for i=1:length(days)
    strt=num2str(str2double(days{i}));

    WL_filepath=[windlidardata_path '/windlidar' strt(3:8) '.nc'];
    finfo = ncinfo(WL_filepath);
    data = [];
    for k = 1:length(finfo.Variables)
        var = finfo.Variables(k).Name;
        data.(var) = ncread(WL_filepath,var);
    end
    data = renameStructField(data,'Uall','u');
    data = renameStructField(data,'Vall','v');
    data = renameStructField(data,'MatlabTime','time');
    
    WL = data;
    w_tt=1;
    for tt=1:7:length(WL.time)-6
        WL_mean.time(w_tt)=mean(WL.time(tt:tt+6));
        WL_mean.u(:,w_tt)=nanmean(WL.u(:,(tt:tt+6)),2)';
        WL_mean.v(:,w_tt)=nanmean(WL.v(:,(tt:tt+6)),2)';
        w_tt=w_tt+1;
    end
    
    w_pp=1;
    for pp=1:2:length(WL.Height)-1
        WL_meanp.Height(w_pp)=mean(WL.Height(pp:pp+1));
        WL_meanp.u(w_pp,:)=nanmean(WL_mean.u((pp:pp+1),:),1)';
        WL_meanp.v(w_pp,:)=nanmean(WL_mean.v((pp:pp+1),:),1)';
        w_pp=w_pp+1;
    end
    
    z_mean = repmat(WL_meanp.Height,1,length(WL_mean.time'));
    t_mean = repmat(WL_mean.time',1,length(WL_meanp.Height))';
    z_mean_all=[z_mean_all z_mean];
    t_mean_all=[t_mean_all t_mean];
    
    winds_u = WL_meanp.u(:,:);
    winds_v = WL_meanp.v(:,:);
    winds_u_all=[winds_u_all winds_u];
    winds_v_all=[winds_v_all winds_v];
    
    
    
    %read radar data
    radar_filepath=[cloudradardata_path '/' strt '_ny-alesund_categorize.nc'];
    radar= readRemoteSensing_NyAlesund(radar_filepath);
    radar_time = radar.time;
    radar_time(~isfinite(radar_time(i))) = nan;
    radar_timetot=[radar_timetot;radar_time];
    radar_height =radar.height;
    Z = radar.Z;
    Z(~isfinite(Z)) = nan;
    Z_tot= [Z_tot Z];
    cloudtop=NaN(length(Z(1,:)),1);
    for x=1:length(Z(1,:))
        cloudtop(x) = radar_height(min(find(isnan(Z(:,x)))));
    end  
    
        
    
    %read radiosonde data
    if strcmp(strt, '20200401')
        output = import_soundings_NYA(soundingdata_path,[strt(1:8) '17']);
    else
        output = import_soundings_NYA(soundingdata_path,[strt(1:8) '11']);
    end
    radiosond_z=output.GeopHgt;
    radiosond_T=output.Temp;
    radiosond_time=output.datevec;
     
    
    %Select cloud top temp
    if strcmp(strt, '20191108') || strcmp(strt, '20200401')
        cloudtop_alt=1800;
        [~,idz]=min(abs(cloudtop_alt-radiosond_z));
        cloudtoptemp=radiosond_T(idz)-273.15;
        radiosond_time=floor(radiosond_time(10))+0.6;
    else
        [~,idy]=min(abs(radiosond_time(10)-radar_time));
        cloudtop_alt=mean(cloudtop(idy-30:idy+30));
        [~,idz]=min(abs(cloudtop_alt-radiosond_z));
        cloudtoptemp=radiosond_T(idz)-273.15;
        radiosond_time=radiosond_time(10);
    end
    
     if strcmp(strt, '20191111')
        output2 = import_soundings_NYA(soundingdata_path,[strt(1:8) '19']);
        radiosond_z2=output2.GeopHgt;
        radiosond_T2=output2.Temp;
        radiosond_time2=output2.datevec;
        [~,idy2]=min(abs(radiosond_time2(10)-radar_time));
        cloudtop_alt2=mean(cloudtop(idy2-30:idy2+30));
        [~,idz2]=min(abs(cloudtop_alt2-radiosond_z2));
        cloudtoptemp2=radiosond_T2(idz2)-273.15; 
        cloudtoptemp=[cloudtoptemp cloudtoptemp2 ];
        cloudtop_alt=[cloudtop_alt cloudtop_alt2 ];
        radiosond_time=[radiosond_time radiosond_time2(10)];
    end
    
   
    %Cloud top for plotting
    radiosond_time_all=[radiosond_time_all radiosond_time];
    cloudtopalt_all= [cloudtopalt_all cloudtop_alt];
    cloudtoptemp_all=[cloudtoptemp_all cloudtoptemp];
    
    
    
    %Select temperature at cloud top for INP
    if strcmp(strt, '20191109')
        heightlim=2200;
    else
        heightlim=4000;
    end
    
    %get interpolated radiosonde
    outputI=interpolate_radiosondes(soundingdata_path,strt,heightlim);
    
    radiosond_zI=outputI.alt;
    radiosond_tI=outputI.time;
    radiosond_TI=outputI.temp_inter_heighttime;
    cloudtoptempI=NaN(length(radar_time),1);
    for p=1:length(radar_time)
        [~,alt_id]=min(abs(cloudtop(p)-radiosond_zI));
        [~,time_id]=min(abs(radar_time(p)-radiosond_tI));
        cloudtoptempI(p)=radiosond_TI(alt_id,time_id)-273.15;
    end
    
    if strcmp(strt, '20200401')
        id_inp2=INP_t2 >= datenum(strt,'yyyymmdd') & INP_t2 <= datenum(num2str(str2double(strt)+1),'yyyymmdd');
        INP_tempcloudtop=INP2(INP_Temp2==floor(min(cloudtoptempI)),id_inp2);
        INP_dt=INP_t2(id_inp2);
    else
        id_inp=INP_t >= datenum(strt,'yyyymmdd') & INP_t <= datenum(num2str(str2double(strt)+1),'yyyymmdd');
        INP_tempcloudtop=INP(INP_Temp==floor(min(cloudtoptempI)),id_inp);
        INP_dt=INP_t(id_inp);
    end
    if isempty(INP_tempcloudtop)
        INP_tempcloudtop=NaN(1,length(INP_dt));
    end
    
    INP_t_all=[INP_t_all ;INP_dt];
    INP_tempcloudtop_all=[INP_tempcloudtop_all INP_tempcloudtop];
   
    disp(strt)
end


%get log data of HoloBalloon (needed for plotting the path)
log=importlog_NYA(HOLIMOlogdata_path);


%% Holimo data reading
Ndropletlarge_all=[];
N_icesmall_all=[];
N_ice_all=[];
Ndropletsmall_all=[];
balloon_time_all=[];
N_droplets_all=[];
balloon_time_allSIP=[];
balloon_time_all_plotting=[];
balloon_height_all_plotting=[];


for j=1:length(data_str)
     
    %read holimo data
    holodata=readHoloBalloon([HOLIMOdata_path data_str{j} '_t' time_resolution '.nc']);
    
    %Get balloon time and height
    balloon_time = holodata.instData_timeGPS;
    balloon_height = holodata.instData_height;    
    datesounding=datestr(holodata.instData_timeGPS(1), 'YYYYmmDD');
    
    %Get radiosonde interpolated
    output=interpolate_radiosondes(soundingdata_path,datesounding,2000);
    radiosond_z=output.alt;
    radiosond_t=output.time;
    radiosond_T=output.temp_inter_heighttime;
    radiosond_RH=output.RH_inter_heighttime;
    
    balloon_temp=NaN(length(balloon_time),1);
    balloon_RH=NaN(length(balloon_time),1);
    for i=1:length(balloon_height)
        [~,alt_id]=min(abs(balloon_height(i)-radiosond_z));
        [~,time_id]=min(abs(balloon_time(i)-radiosond_t));
        balloon_temp(i)=radiosond_T(alt_id,time_id)-273.15;
        balloon_RH(i)=radiosond_RH(alt_id,time_id);
        
    end
    
    if  strcmp(datesounding, '20200401')
        id_inpb2=INP_t2 >= datenum(datesounding,'yyyymmDD') & INP_t2 <= datenum(num2str(str2double(datesounding)+1),'yyyymmDD');
        INP_tempballoon=INP2(INP_Temp2==floor(mean(balloon_temp)),id_inpb2);
        INP_balloon_dt=INP_t2(id_inpb2);
    else
        id_inpb=INP_t >= datenum(datesounding,'yyyymmDD') & INP_t <= datenum(num2str(str2double(datesounding)+1),'yyyymmDD');       
        INP_tempballoon=INP(INP_Temp==floor(mean(balloon_temp)),id_inpb);
        INP_balloon_dt=INP_t(id_inpb);
        
    end
    
    %Ice selection and putting together classes
    binSize = holodata.diameter;
    binWidth = holodata.diameterLogBinWidth;
    
    
    PSDlogNorm = zeros(size(holodata.Ice_PSDlogNormMajsiz));
    N_ice=holodata.Ice_concentration;

    %Smass ice crystals used for SIP detection are selected from the ice
    %categories 'Column','Plates', and 'Small' ice
    if strcmp(datestr(holodata.instData_timeGPS(1), 'YYYYmmDDHH'), '2019111013')
        PSDlogNorm = NaN(size(holodata.Ice_PSDlogNormMajsiz));
        N_ice_mean=nanmean(holodata.Ice_concentration);
        N_timemean=nanmean(holodata.instData_timeGPS);
        N_ice=NaN(length(holodata.Ice_concentration),1);     
    elseif strcmp(datestr(holodata.instData_timeGPS(1), 'YYYYmmDDHH'), '2019111010')
        PSDlogNorm = NaN(size(holodata.Water_PSDlogNormMajsiz));
        N_ice_mean2=nanmean(holodata.Ice_concentration);
        N_timemean2=nanmean(holodata.instData_timeGPS);
        N_ice=NaN(length(holodata.Water_concentration),1);
    else     
        if isfield(holodata,'Ice_Column_concentration')
            PSDlogNorm =PSDlogNorm+holodata.Ice_Column_PSDlogNormMajsiz;
        end
        if isfield(holodata,'Ice_Plate_concentration')
            PSDlogNorm =PSDlogNorm+ holodata.Ice_Plate_PSDlogNormMajsiz;
        end
        if isfield(holodata, 'Ice_Small_concentration')
            PSDlogNorm =PSDlogNorm+holodata.Ice_Small_PSDlogNormMajsiz;
        end
    end
    %Selection of small ice particles
    idx_small = max(find(binSize<=ice_small));
    
    %idx_large = min(find(binSize>ice_small));
    N_ice_part = PSDlogNorm.*binWidth';
    N_ice_small = nansum(N_ice_part(:,1:idx_small),2);
        
    %Water selection small vs large
    droplet_PSDlogNorm = holodata.Water_PSDlogNormMajsiz;
    idx_droplet_large = max(find(binSize<=droplet_large));
    idx_droplet_small = max(find(binSize<=droplet_small));
    N_droplet = droplet_PSDlogNorm.*binWidth';
    N_droplet_large = nansum(N_droplet(:,idx_droplet_large+1:end),2);
    N_droplet_small = nansum(N_droplet(:,1:idx_droplet_small),2);
    N_droplets=holodata.Water_concentration;
    
    %remove data at ground
    idz=find(balloon_height >=150);
    [idz1,~]=find(balloon_height >=150 & holodata.Water_concentration>dropletslim | balloon_RH>rhlim );    
    Ndropletsmall_all=[Ndropletsmall_all NaN N_droplet_small(idz)'];
    Ndropletlarge_all=[Ndropletlarge_all NaN N_droplet_large(idz)'];
    N_icesmall_all=[N_icesmall_all NaN N_ice_small(idz1)'];
    N_ice_all=[N_ice_all NaN N_ice(idz)'];
    balloon_time_all=[balloon_time_all NaN balloon_time(idz)'];
    N_droplets_all=[N_droplets_all NaN N_droplets(idz)'];
    INP_tempballoon_all=[INP_tempballoon_all INP_tempballoon];
    INP_balloon_dt_all=[INP_balloon_dt_all INP_balloon_dt'];
    balloon_time_allSIP=[balloon_time_allSIP NaN balloon_time(idz1)'];
    
    balloon_time_all_plotting=[balloon_time_all_plotting NaN balloon_time'];
    balloon_height_all_plotting=[balloon_height_all_plotting NaN balloon_height'];

end

N_droplets_all(N_droplets_all<=1.5e-2)=NaN;
Ndropletlarge_all(Ndropletlarge_all==0)=NaN;
N_icesmall_all(N_icesmall_all==0)=NaN;
N_ice_all(N_ice_all==0)=NaN;
INP_tempballoon_all(INP_tempballoon_all==0)=NaN;


[INP_balloon_dt_allunique,~,c]=unique(INP_balloon_dt_all);
INP_tempballoon_allunique=NaN(length(unique(c)),1);
for d=1:length(unique(c))
    e=find(d==c);
    INP_tempballoon_allunique(d)=nanmean(INP_tempballoon_all(e));
end


%Because on 12.11 INPC at HoloBalloon is = 0/Nan, draw a line at lower
%limit of detection of DRINCZ
inpsample1211=[];
for a=1:length(INP_balloon_dt_allunique)
    if strcmp(datestr(INP_balloon_dt_allunique(a), 'YYYYmmDD'), '20191112')
        inpsample1211=[inpsample1211 INP_balloon_dt_allunique(a)];
    end
end





%%Figure
fig = figure;
fig.Units = 'centimeters';
fig.Position = [0 1 53 63];
fig.PaperPositionMode = 'auto';

sp1=subplot(5,2,1);
yyaxis left
c1 =[0 0.2 0.6] ;
c2 = [0.1 0.5 0.1];
ax = gca;
ax.YAxis(2).Color = c2;
ax.YAxis(1).Color = c1;
ax.XAxis.Color = [0 0 0];

plot(weather3.t,weather3.Temp2,'-', 'color', c1, 'LineWidth', LW);
hold on
ylim([-23 2])
ylabel('Temperature (°C)')

yyaxis right
plot(weather3.t,weather3.pressure,'-', 'color', c2, 'LineWidth', LW);
ylim([1000 1020])
set(gca,'YTick','')
xlim([weather3.t(658) weather3.t(end-345)])
text(weather3.t(658)+30/(24*60), 1018,'(a)' ,'Color', 'k','FontSize',22)
datetick('x','keeplimits')
set(gca,'Fontsize',FS);
set(gca,'XTickLabel','')


sp2=subplot(5,2,2);
yyaxis left
c1 =[0 0.2 0.6] ;
c2 = [0.1 0.5 0.1];
ax = gca;
ax.YAxis(2).Color = c2;
ax.YAxis(1).Color = c1;
ax.XAxis.Color = [0 0 0];
plot(weather.t,weather.Temp2,'-', 'color', c1, 'LineWidth', LW);
hold on
plot(weather1.t,weather1.Temp2, '-', 'color', c1, 'LineWidth', LW);
ylim([-23 2])
set(gca,'YTick','')

yyaxis right
plot(weather.t,weather.pressure,'-', 'color', c2, 'LineWidth', LW);
plot(weather1.t,weather1.pressure,'-', 'color', c2, 'LineWidth', LW);
ylim([1000 1020])
ylabel('Pressures (hPa)')
xlim([weather.t(242) weather.t(end-660)])
datetick('x','keeplimits')
set(gca,'Fontsize',FS);
set(gca,'XTickLabel','')


sp5=subplot(5,2,3);
caxis([speed_lims.min speed_lims.max])
turbo;
cmap3 = turbomap(1:12:end,:);
colormap(sp5,cmap3);
ylim([0 height_lim])
xlim([startDate+0.4583 endDate-0.25]);
set(gca,'XTickLabel','')
set(gcf,'paperpositionmode','auto')
ylabel('Altitude (m a.s.l.)');
set(gca,'Fontsize',FS);
box on;
set(gca, 'Layer', 'top')
nb_elem = numel(winds_u_all);
windbarbs(reshape(winds_u_all,1,nb_elem),reshape(winds_v_all,1,nb_elem),...
    reshape(t_mean_all,1,nb_elem),reshape(z_mean_all(:,:),1,nb_elem)+station_altitude_nyalesund,...
    width_barbs,[],windline,speed_lims);

p2=plot(log.instData.data.timeGPS,log.instData.data.height,'k-','LineWidth',LW);

leg=legend([p2],'HoloBalloon','Location','northeast');
leg.ItemTokenSize = [10,20];
text(startDate+0.485, 2600,'(b)','Color', 'k','FontSize',22)



sp6=subplot(5,2,4);
caxis([speed_lims.min speed_lims.max])
cbar3 = colorbar;
turbo;
cmap3 = turbomap(1:12:end,:);
colormap(sp6,cmap3);
ts = sprintf('Horizontal \nwind speed (m s^{-1})');
cbar3.Label.String =ts;
cbar3.Label.FontSize = FS+6;

ylim([0 height_lim])
xlim([startDatefeed+0.2083 endDatefeed-0.333]);

set(gca,'YTick','');
set(gca,'XTickLabel','')
set(gcf,'paperpositionmode','auto')
set(gca,'Fontsize',FS);
box on;
set(gca, 'Layer', 'top')
nb_elem = numel(winds_u_all);
windbarbs(reshape(winds_u_all,1,nb_elem),reshape(winds_v_all,1,nb_elem),...
    reshape(t_mean_all,1,nb_elem),reshape(z_mean_all(:,:),1,nb_elem)+station_altitude_nyalesund,...
    width_barbs,[],windline,speed_lims);

p2=plot(log.instData.data.timeGPS,log.instData.data.height,'k-','LineWidth',LW);
box on
set(gca, 'Layer', 'top')




sp7 = subplot(5,2,5);
p = pcolor(radar_timetot,radar_height,Z_tot);
p.EdgeColor = 'None';
turbo;
cmap = turbomap(1:12:end,:);
colormap(cmap);
caxis([-40 20]);
hold on
p2=plot(log.instData.data.timeGPS,log.instData.data.height,'k-','LineWidth',LW);
set(gcf,'paperpositionmode','auto')
ylabel('Altitude (m a.s.l.)');
ylim([0 height_lim]);
set(gca,'Fontsize',FS);
leg=legend([p2 ],'HoloBalloon','Location','northeast');
leg.ItemTokenSize = [10,20];

box off;
set(gca, 'Layer', 'top')
set(gca,'XTickLabel','')
for l=1:length(radiosond_time_all)
    text(radiosond_time_all(l)-0.06, double(cloudtopalt_all(l))+130,[num2str(cloudtoptemp_all(l),3) '°C'],'Color', 'k','FontSize',21, 'FontWeight', 'bold')
end
xlim([startDate+0.4583 endDate-0.25]);
text(startDate+0.485, 2600,'(c)','Color', 'k','FontSize',22)
box on
set(gca, 'Layer', 'top')


sp8 = subplot(5,2,6);
p = pcolor(radar_timetot,radar_height,Z_tot);
p.EdgeColor = 'None';
cbar = colorbar;
turbo;
cmap = turbomap(1:12:end,:);
colormap(cmap);
caxis([-40 20]);
cbar.Label.String = {'Reflectivity (dBZ)'};
cbar.Label.FontSize = FS;
hold on
p2=plot(log.instData.data.timeGPS,log.instData.data.height,'k-','LineWidth',LW);
set(gcf,'paperpositionmode','auto')
ylim([0 height_lim]);
set(gca,'Fontsize',FS);
box off;
set(gca, 'Layer', 'top')

set(gca,'XTickLabel','')
set(gca,'YTicklabel','')
for l=1:length(radiosond_time_all)
    text(radiosond_time_all(l)-0.25, double(cloudtopalt_all(l))+130,[num2str(cloudtoptemp_all(l),3) '°C'],'Color', 'k','FontSize',21, 'FontWeight', 'bold')
end
xlim([startDatefeed+0.2083 endDatefeed-0.333]);
box on
set(gca, 'Layer', 'top')



sp9 = subplot(5,2,7);
p1 = plot(balloon_time_all,Ndropletlarge_all,'Color',[0.8500 0.3250 0.0980],'LineStyle','-','LineWidth',LW);
hold on
p2 = plot(balloon_time_all,N_droplets_all,'Color',[0 0 0],'LineStyle','-','LineWidth',LW);
set(gca,'YScale','log')
ylim([0.002 30])
set(gca,'YTick',[0.001 0.01 0.1 1 10])
ylabel({'CDNC (cm^{-3})'});
xlim([startDate+0.4583 endDate-0.25]);

set(gca,'Fontsize',FS);
box off;
set(gca,'XTickLabel','')
text(startDate+0.485, 10,'(d)','Color', 'k','FontSize',22)
box on
set(gca, 'Layer', 'top')



sp10 = subplot(5,2,8);
p1 = plot(balloon_time_all,Ndropletlarge_all,'Color',[0.8500 0.3250 0.0980],'LineStyle','-','LineWidth',LW);
hold on
p2 = plot(balloon_time_all,N_droplets_all,'Color',[0 0 0],'LineStyle','-','LineWidth',LW);
set(gca,'YScale','log')
ylim([0.002 30])
set(gca,'YTick',[0.001 0.01 0.1 1 10])
leg = legend([p1 p2],[' SLDNC'],[' CDNC'],'Location','northeastoutside');
leg.ItemTokenSize = [10,20];
set(gca,'TickLength',[0.04, 0.01])
xlim([startDatefeed+0.2083 endDatefeed-0.333]);
set(gca,'XTick',startDatefeed+0.5:datenum(0,0,1,0,0,0):endDatefeed);
set(gca,'Fontsize',FS);
set(gca,'XTickLabel','')
set(gca,'YTicklabel','')
box on
set(gca, 'Layer', 'top')


sp11 = subplot(5,2,9);
p1 = plot(balloon_time_allSIP,N_icesmall_all.*1e3,'Color',[1 0 0],'LineStyle','-','LineWidth',LW);
hold on
p2 = plot(balloon_time_all, N_ice_all.*1e3,'Color',[0 0 0],'LineStyle','-','LineWidth',LW);
p3=plot(N_timemean ,N_ice_mean.*1e3, 'Color',[0 0 0],'Marker','o','LineStyle','none', 'MarkerSize', 20);
p5=plot(N_timemean2 ,N_ice_mean2.*1e3, 'Color',[0 0 0],'Marker','o','LineStyle','none', 'MarkerSize', 20);
p3.LineWidth=2;
p5.LineWidth=2;
p4=plot(INP_t_all,INP_tempcloudtop_all,'Color',[0.3010 0.7450 0.9330],'Marker','+','LineStyle','none', 'MarkerSize', 23);
p4.LineWidth=2;
p6=plot(INP_balloon_dt_allunique,INP_tempballoon_allunique,'Color',[0.1 0.1 0.6],'Marker','+','LineStyle','none', 'MarkerSize', 20);
p6.LineWidth=2;
p7=plot([inpsample1211(1) inpsample1211(end)], [1.4e-4 1.4e-4], 'Color',[0.1 0.1 0.6], 'LineStyle', '--','LineWidth',LW);
hold on
set(gca,'YScale','log')
ylim([0.00001 100])
set(gca,'YTick',[0.0001 0.001 0.01 0.1 1 10 100])
ylabel({'ICNC & INPC (L^{-1})'});

xlim([startDate+0.4583 endDate-0.25]);
set(gca,'XTick',(startDate+0.5):datenum(0,0,1,0,0,0):endDate-0.25);
set(gca,'Fontsize',FS);
box on;
set(gca, 'Layer', 'top')
datetick('x','yyyy/mm/dd','keepticks', 'keeplimits')%('keeplimits');
text(startDate+0.485, 20,'(e)','Color', 'k','FontSize',22)



sp12 = subplot(5,2,10);
p1 = plot(balloon_time_allSIP,N_icesmall_all.*1e3,'Color',[1 0 0],'LineStyle','-','LineWidth',LW);
hold on
p2 = plot(balloon_time_all, N_ice_all.*1e3,'Color',[0 0 0],'LineStyle','-','LineWidth',LW);
p3=plot(N_timemean ,N_ice_mean.*1e3, 'Color',[0 0 0],'Marker','o','LineStyle','none', 'MarkerSize', 20);
p4=plot(INP_t_all,INP_tempcloudtop_all,'Color',[0.3010 0.7450 0.9330],'Marker','+','LineStyle','none', 'MarkerSize', 20);
p6=plot(INP_balloon_dt_allunique,INP_tempballoon_allunique,'Color',[0.1 0.1 0.6],'Marker','+','LineStyle','none', 'MarkerSize', 20);
p7=plot([inpsample1211(1) inpsample1211(end)], [1.4e-4 1.4e-4], 'Color',[0.1 0.1 0.6], 'LineStyle', '--','LineWidth',LW);

p4.LineWidth=2;
p6.LineWidth=2;
p3.LineWidth=2;
plot([balloon_time_all(1) balloon_time_all(end)], [1 1], '--', 'color', 'k', 'LineWidth', 0.5)
plot([balloon_time_all(1) balloon_time_all(end)], [10 10], '--', 'color', 'k', 'LineWidth', 0.4)

hold on
set(gca,'YScale','log')
ylim([0.00001 100])
set(gca,'YTick',[0.0001 0.001 0.01 0.1 1 10 100])
leg = legend([p1 p2 p3 p4 p6 p7],[' ICNC_{pr<',num2str(round(binSize(idx_small)*1e6,0)), char(181) 'm','}'],' Total ICNC',' Mean ICNC',' INPC_{CT}',' INPC_{HB}', ' INPC_{lim}', 'Location','northeastoutside');
leg.ItemTokenSize = [10,20];
xlim([startDatefeed+0.2083 endDatefeed-0.333]);
set(gca,'TickLength',[0.04, 0.01])
set(gca,'XTick',startDatefeed+0.5:datenum(0,0,1,0,0,0):endDatefeed);
set(gca,'Fontsize',FS);
box on
set(gca, 'Layer', 'top')
set(gca,'YTicklabel','')
datetick('x','yyyy/mm/dd', 'keeplimits','keepticks')

sp1.Position = [0.07 0.77 0.7 0.15];
sp2.Position = [0.78 0.77 0.07 0.15];

sp5.Position =[0.07 0.59 0.7 0.15] ;
sp6.Position =[0.78 0.59 0.07 0.15] ;

sp7.Position =[0.07 0.41 0.7 0.15] ;
sp8.Position =[0.78 0.41 0.07 0.15] ;

sp9.Position =[0.07 0.23 0.7 0.15] ;
sp10.Position =[0.78 0.23 0.07 0.15] ;

sp11.Position =[0.07 0.05 0.7 0.15] ;
sp12.Position =[0.78 0.05 0.07 0.15] ;

end