function Figure4(soundingdata_path)
% soundingdata_path -> path for radiosonde data

datelong={'20191108','20191109','20191110','20191111','20191112','20200401'};

%constant for plotting
FS=24;
windbarspos=[2;1;0;5;5;-6];
subplotpos=[0.07; 0.21;0.35;0.49;0.63;0.77];

for m=1:length(datelong)
    date=datelong{m};
    
    %get radiosonde data
    if strcmp(date, '20200401')
        output = import_soundings_NYA(soundingdata_path,[date(1:8) '17']);
    else
        output = import_soundings_NYA(soundingdata_path,[date(1:8) '11']);
    end
    
    radiosond_z=output.GeopHgt;
    radiosond_T=output.Temp-273.15;
    radiosond_RH=output.RH;
    
    %calculate relative humidity for ice
    esw=2.53*10e11*exp(-5420./(radiosond_T+273.15));
    esi=3.64*10e12*exp(-6148./(radiosond_T+273.15));
    RHi=radiosond_RH.*esw./esi;
    
    %Plot
    fig=figure(1);
    fig.Units = 'centimeters';
    fig.Position = [0 0 55 25.5];
    fig.PaperPositionMode = 'auto';
    sp=subplot(1,6,m);
    sp.Position=[subplotpos(m)    0.1000    0.112    0.8];
    ax1=gca;
    
    %Plot radiosonde temperature
    plot(radiosond_T(4:end),radiosond_z(4:end), 'LineWidth', 2, 'color',[0.6350 0.0780 0.1840]);
    ylim([0 3000])
    ax1.XAxis.Color = [0.6350 0.0780 0.1840];
    set(gca,'Fontsize',FS);
    hold on
    
    %Labels
    if m==1
        ylabel('Altitude (m a.s.l.)')
    else
        set(ax1,'YTick','')
    end
    if m==3
        xlabel('                        Temperature (°C)')
    end
    if m==1 || m==2
        xlim([-25 0])
    elseif m==3
        xlim([-25 -5])
    elseif m==4 || m==5
        xlim([-20 0])
    elseif m==6
        xlim([-30 -10])
    end
    
    %Plot RH and RHi on second ax
    ax2=axes('position',ax1.Position);
    p1=plot(radiosond_RH(4:end),radiosond_z(4:end), 'LineWidth', 2, 'color', [0.6 0.6 0.6]);
    hold on
    p2=plot(ax2,RHi(4:end),radiosond_z(4:end), 'LineWidth', 2, 'color', [0.2 0.2 0.2]);
    plot([100 100],[0 3000],'--', 'LineWidth',0.5, 'Color', [0 0 0])
    ylim([0 3000])
    set(ax2,'XTick',[40 60 80 100 120])
    
    %Labels
    if m==3 || m==4
        xlim([20 125])
        set(ax2,'XTick',[40  80  120])
    elseif m==5
        xlim([50 120])
    elseif m==length(datelong)
        xlim([60 140])
    else
        xlim([60 120])
    end
    set(ax2, 'YTick', '')
    if m==length(datelong)
        leg=legend([p1 p2], 'RH water', 'RH ice');
        leg.ItemTokenSize = [10,20];
        leg.Position=[0.89    0.82    0.0762    0.0780];
    end
    if m==3
        xlabel('                            Relative humidity (%)')
    end
    
    %locating the axes
    ax2.XAxisLocation = 'top';
    ax2.YAxisLocation = 'right';
    ax2.Color = 'none';
    ax1.Box = 'off';
    ax2.Box = 'off';
    
    %add date in subplots
    limitx=xlim;
    text((limitx(2)-limitx(1))/5+limitx(1),2900, [date(1:4) '/'  date(5:6) '/'  date(7:8)],'FontSize',22,'BackgroundColor',[1 1 1])
    set(gca,'Fontsize',FS); 
end
end
