function Figure7b(HOLIMOdata_path)
%HOLIMOdata_path -> path to HOLIMO data of the second flight on of 11
%November 2019 in 30sec resolution

%Define dates
strtdate='20191111170000';
enddate='20191111184500';
startDate = dtstr2dtnummx(cellstr(strtdate),'yyyyMMddHHmmss');
endDate = dtstr2dtnummx(cellstr(enddate),'yyyyMMddHHmmss');


%Values to change depending on wishes
FS=26;
ice_small = 110e-6;


% Holimo data reading
data_str={'191111_2'};
time_resolution='30';

holodata=readHoloBalloon([HOLIMOdata_path data_str{1} '_t' time_resolution '.nc']);

%Get balloon time and height
balloon_time = holodata.instData_timeGPS;


%Select time steps for plotting
idx=holodata.time >= datenum(strtdate,'yyyymmddHHMMSS') & balloon_time <= datenum(enddate,'yyyymmddHHMMSS');
balloon_time=balloon_time(idx);

%Ice selection and putting together classes
binSize = holodata.diameter;
binWidth = holodata.diameterLogBinWidth;
PSDlogNorm = zeros(size(holodata.Ice_PSDlogNormMajsiz));

%Smass ice crystals used for SIP detection are selected fro the ice
%categories 'Column','Plates', and 'Small' ice
if isfield(holodata,'Ice_Column_concentration')
    PSDlogNorm =PSDlogNorm+holodata.Ice_Column_PSDlogNormMajsiz;
end
if isfield(holodata,'Ice_Plate_concentration')
    PSDlogNorm =PSDlogNorm+ holodata.Ice_Plate_PSDlogNormMajsiz;
end
if isfield(holodata, 'Ice_Small_concentration')
    PSDlogNorm =PSDlogNorm+holodata.Ice_Small_PSDlogNormMajsiz;
end


idx_small = max(find(binSize<=ice_small));
N_ice = PSDlogNorm.*binWidth';
N_ice_small = nansum(N_ice(:,1:idx_small),2);
N_ice_large = nansum(N_ice(:,idx_small+1:end),2);

%change 0 with NaN values for log-plots
N_ice_small(N_ice_small==0)=NaN;
N_ice_large(N_ice_large==0)=NaN;
N_icelarge_all= N_ice_large(idx);
N_icesmall_all=N_ice_small(idx);


%Select ice categories
N_column=holodata.Ice_Column_concentration;
N_col_aged=holodata.Ice_Column_aged_concentration;
N_dfrozen=holodata.Ice_Droplet_frozen_concentration;
N_small=holodata.Ice_Small_concentration;
N_CCC=holodata.Ice_CCC_concentration;
N_Aged=holodata.Ice_Aged_concentration;
N_branch=holodata.Ice_Branch_concentration;
N_plate=holodata.Ice_Plate_concentration;
N_recirc=holodata.Ice_Recirculation_concentration;

%merge categories for bar plotting
bar_col=N_column+N_plate+N_small;
bar_frozen=N_dfrozen;
bar_aged=N_Aged+N_branch+N_col_aged;
bar_recirc=N_recirc+N_CCC;


bar_aged_all=bar_aged(idx);
bar_frozen_all=bar_frozen(idx);
bar_col_all=bar_col(idx);
bar_recirc_all=bar_recirc(idx);

%divide with total ICNC for percent plotting
ratio_aged=bar_aged_all./holodata.Ice_concentration(idx);
ratio_small=N_icesmall_all./holodata.Ice_concentration(idx);
ratio_recirc=bar_recirc_all./holodata.Ice_concentration(idx);
ratio_large=N_icelarge_all./holodata.Ice_concentration(idx);
ratio_dfrozen=bar_frozen_all./holodata.Ice_concentration(idx);

bar_ratio=[ratio_small,ratio_large,ratio_aged,ratio_recirc,ratio_dfrozen];

%plotting
fig = figure(1);
fig.Units = 'centimeters';
fig.Position = [0 1 52. 30.];
fig.PaperPositionMode = 'auto';

sp1 = subplot(2,1,1);
plot(balloon_time,N_ice_small(idx).*1e3,'Color',[0 0 0],'LineStyle','-','LineWidth',2.5);
hold on
ylabel('ICNC (L^{-1})');
bar_all=[bar_col_all,  bar_aged_all,bar_recirc_all, bar_frozen_all  ];
b=bar(balloon_time,bar_all.*1e3, 1, 'stacked','FaceColor','flat', 'EdgeColor','k');
b(1).CData=[0.1 0.5 1];
b(2).CData=[1 0.7 0.3];
b(3).CData=[0.6 0.3 0.1];
b(4).CData=[0.2 0.7 0.3];
leg = legend(['ICNC_{pr<106' char(181) 'm}'],'Column', 'Aged','Recirculation','Frozen drops','Location','northeastoutside');
leg.ItemTokenSize = [10,20];
xlim([startDate endDate-0.0001]);
ylim([0 180])
set(gca, 'SortMethod', 'depth')
set(gca,'Fontsize',FS);
set(gca,'XTick',startDate:datenum(0,0,0,0,15,0):endDate);
set(gca,'XTickLabel','')
set(gca,'TickLength',[0.01, 0.01],'TickDir','out')


sp2= subplot(2,1,2);
b=bar(balloon_time,bar_ratio, 1, 'stacked','FaceColor','flat', 'EdgeColor','k');
b(1).CData=[0.1 0.5 1];
b(2).CData=[0.4940 0.1840 0.5560];
b(3).CData=[1 0.7 0.3];
b(4).CData=[0.6 0.3 0.1];
b(5).CData=[0.2 0.7 0.3];
leg = legend(['ICNC_{pr<106' char(181) 'm}'],['ICNC_{pr>106' char(181) 'm}'], 'Aged','Recirculation','Frozen drops','Location','northeastoutside');
leg.ItemTokenSize = [10,20];
set(gca,'TickLength',[0.01, 0.01],'TickDir','out')
set(gca,'XTick',startDate:datenum(0,0,0,0,15,0):endDate);
xlim([startDate endDate-0.0001]);
xlabel('Time (UTC)');
ylim([0 1])
datetick('x','HH:MM','keeplimits','keepticks');
set(gca,'Fontsize',FS);
ylabel({'Fraction of' ; 'total ICNC'});


sp1.Position=[0.1 0.37 0.74 0.55];
sp2.Position=[0.1 0.11 0.74 0.21];

end