function Figure8(cloudradardata_path,ceilodata_path,soundingdata_path,HOLIMOdata_path)
% cloudradardata_path -> path to cloud radar data on 01 April 2020
% ceilodata_path= -> path to ceilometer data on 01 April 2020
% HOLIMOdata_path -> path to HoloBalloon data on 01 April 2020 (time resolution 60sec)
% soundingdata_path -> path to radiosonde data on 01 April 2020

%define dates
strtdate='20200401110000';
enddate='20200401150000';
startDate = dtstr2dtnummx(cellstr(strtdate),'yyyyMMddHHmmss');
endDate = dtstr2dtnummx(cellstr(enddate),'yyyyMMddHHmmss');
data_str={'200401_1'};
time_resolution='60';


%Values to change depending on wishes
FS=24;
LW = 1.6;
maxWater=100;
heightlim=8000;


%Get cloud radar data
radar_filepath=[cloudradardata_path  strtdate(1:8) '_ny-alesund_categorize.nc'];
radar= readRemoteSensing_NyAlesund(radar_filepath);
radar_time = radar.time;
radar_time(~isfinite(radar_time)) = nan;
radar_height = radar.height;
Z = radar.Z;
Z(~isfinite(Z)) = nan;


%Select cloud droplet  and ice crystals data for size distribution over time
holodata=readHoloBalloon([HOLIMOdata_path data_str{1} '_t' time_resolution '.nc']);


%Get balloon time and height
balloon_time = holodata.instData_timeGPS;
balloon_height = holodata.instData_height;

%Select time steps for plotting
idx=balloon_time >= datenum(strtdate,'yyyymmddHHMMSS') & balloon_time <= datenum(enddate,'yyyymmddHHMMSS');
balloon_time=balloon_time(idx);
histBinSize=holodata.diameter;
plotData=holodata.Ice_PSDlogNormMajsiz;
plotData=plotData(idx,:);
plotData_CD=holodata.Water_PSDlogNormMajsiz;
plotData_CD=plotData_CD(idx,:);
plotData(~isfinite(plotData))=nan;
plotData_CD(~isfinite(plotData_CD))=nan;

N_ice_tot=holodata.Ice_concentration;
N_water_tot=holodata.Water_concentration;

%Read ceilometer data
fid=fopen([ceilodata_path '/NYA_expanded_' strtdate(1:4)  '-' strtdate(5:6) '.tab']);
C = textscan(fid,' %s %u','HeaderLines',14);
ceilo_time=C{1,1};
cb=C{1,2};
ceilo_time=datetime(ceilo_time,'InputFormat','yyyy-MM-dd''T''HH:mm');
ceilo_t=datenum(ceilo_time);

%Select time cloud base
idx1= ceilo_t >= datenum(strtdate,'yyyymmddHHMM') & ceilo_t <= datenum(enddate,'yyyymmddHHMM');
ct1=ceilo_t(idx1);
cb1=cb(idx1);

% Get radiosonde data
tempheight=[10;1000;2000;3000;4000;5000;6000; 7000];
output1 = import_soundings_NYA(soundingdata_path,[strtdate(1:8) '17']);
radiosond_z1=output1.GeopHgt;
radiosond_T1=output1.Temp-273.15;

for m=1:length(tempheight)
    low=sort(abs(radiosond_z1-tempheight(m)));
    lowest(m)=find(abs(radiosond_z1-tempheight(m))==low(1),1);
end
radiosond_temperatures1=round(radiosond_T1(lowest),1);


%Plot
fig = figure;
fig.Units = 'centimeters';
fig.Position = [0 1 48. 45.];
fig.PaperPositionMode = 'auto';

%Panel 1: cloud radar and radiosonde temperature
sp1 = subplot(3,1,1);
sp1.Position=[0.1 0.69 0.7 0.26];
p = pcolor(radar_time,radar_height,Z);
p.EdgeColor = 'None';
cbar = colorbar;
cbar.Label.String = {'Reflectivity (dBZ)'};
cbar.Label.FontSize = FS+6;
turbo;
cmap = turbomap(1:12:end,:);
caxis([-30 20]);
cbar.Position(1) = cbar.Position(1) +0.13;
cbar.Position(3) = 0.7.*cbar.Position(3);
colormap(cmap);
xlim([startDate endDate]);
set(gca,'TickLength',[0.02 0.04],'TickDir','out');
set(gca,'XTick','')
set(gcf,'paperpositionmode','auto')
ylabel('Altitude (m a.s.l.)');
ylim([0 heightlim]);
set(gca,'Fontsize',FS);
box on;
set(gca, 'Layer', 'top')
hold on;
p1=plot(ct1, cb1, 'k.','MarkerSize',8);
p2=plot(balloon_time,balloon_height,'k-','LineWidth',2);
leg=legend([p1 p2],'Cloud base','HoloBalloon');
leg.ItemTokenSize = [10,20];
leg.Position=[0.71 0.905 0.075 0.043];
leg.FontSize=20;
tempheight(1)=tempheight(1)+60;
for l=1:length(tempheight)
    text(datenum(2020,04,01,15,06,0), tempheight(l)+15,[num2str(radiosond_temperatures1(l),3) '°C'],'Color', 'k','FontSize',18)
end
text(datenum(2020,04,01,11,05,0), 7500,'(a)' ,'Color', 'k','FontSize',20)
sp1.Position=[0.1 0.69 0.7 0.26];



%Panel 2: cloud droplet properties
sp2 = subplot(3,1,2);
sp2.Position=[0.1 0.4 0.7 0.26];
yyaxis right;
set(gca,'YScale','log')
set(gca,'YTick',[10 20 50 100 200 500])
set(gca,'YTickLabel', {'10'; '20'; '50'; '100'; '200'; '500'; '1000'; '2000'; '5000'},'FontSize',FS)
set(gca,'TickLength',[0.02 0.04],'TickDir','out');
ylim([6 600])
ylabel({['Droplet diameter (' char(181) 'm)']},'FontSize',FS);
set(gca,'Fontsize',FS);
plotData_CD_cor=plotData_CD;
plotData_CD_cor(3,:)=plotData_CD(3,:)+plotData_CD(4,:); %merge bin size 3 & four for plotting
plotData_CD_cor(4,:)=plotData_CD(3,:)+plotData_CD(4,:);
yyaxis left
c2 = [0 0 0];
ax = gca;
ax.YAxis(2).Color = c2;
ax.YAxis(1).Color = c2;
ax.XAxis.Color = c2;
h=pcolor(balloon_time,histBinSize*1e6, plotData_CD_cor');
cmap2 = viridis(10);
cmap2(1,:) = 1;
colormap(gca,cmap2);
cbar2=colorbar;
ts = sprintf('Number density \nd(N)/d(log d) (cm^{-3})');
cbar2.Label.String =ts;
cbar2.Position(1) = cbar2.Position(1) +0.13;
cbar2.Position(3) = 0.7.*cbar2.Position(3);
cbar2.Label.FontSize = FS+6;
caxis(ax,[1e-4 1e1])
ylim([6 600])
set(h, 'EdgeColor', 'none');
set(gca,'ColorScale','log')
set(gca,'YScale','log')
set(gca,'YTick','')
xlim([startDate endDate]);
set(gca,'XTick','')
set(gca,'Fontsize',FS);
text(datenum(2020,04,01,11,05,0), 400,'(b)' ,'Color', 'k','FontSize',20)
box on;
ax2=axes('position',ax.Position);
yyaxis left
ax2.YAxis(2).Color = c2;
ax2.YAxis(1).Color = c2;
ax2.XAxis.Color = c2;
plot(balloon_time,N_water_tot,'Color',c2,'LineStyle','-','LineWidth',LW);
ylabel('CDNC (cm^{-3})');
ylim([1e-2 maxWater]);
set(gca,'Fontsize',FS);
set(gca,'YScale','log')
set(gca,'TickLength',[0.02 0.04],'TickDir','out');
ax2.Color='none';
set(gca,'XTick','')
xlim([startDate endDate]);
yyaxis right
ax2.Color='none';
set(gca,'YTick','')
sp2.Position=[0.1 0.4 0.7 0.26];

%Panel 3: cloud droplet properties
sp3 = subplot(3,1,3);
sp3.Position=[0.1 0.11 0.7 0.26];
yyaxis right
set(gca,'YTick',[5 10 20 50 100 200 500 1000 2000 5000])
set(gca,'YTickLabel', {'5';'10'; '20'; '50'; '100'; '200'; '500'; '1000'; '2000'; '5000'},'FontSize',6)
set(gca,'TickLength',[0.02 0.04],'TickDir','out');
set(gca,'Fontsize',FS);
set(gca,'YScale','log')
ylim([20 3000])
ylabel({['Ice crystal diameter (' char(181) 'm)']},'FontSize',FS);
yyaxis left
c2 = [0 0 0];
ax = gca;
ax.YAxis(2).Color = c2;
ax.YAxis(1).Color = c2;
ax.XAxis.Color = c2;
h=pcolor(balloon_time,histBinSize*1e6, plotData'*1e3);
cmap2 = viridis(10);
cmap2(1,:) = 1;
colormap(gca,cmap2);
cbar2=colorbar;
ts = sprintf('Number density \nd(N)/d(log d) (L^{-1})');
cbar2.Label.String =ts;
cbar2.Position(1) = cbar2.Position(1) +0.13;
cbar2.Position(3) = 0.7.*cbar2.Position(3);
cbar2.Label.FontSize = FS+6;
ax=gca;
caxis(ax,[1e-1 5e1])
ylim([20 3000])
set(h, 'EdgeColor', 'none');
set(gca,'ColorScale','log')
set(gca,'YScale','log')
set(gca,'YTick','')
xlim([startDate endDate]);
set(gca,'Fontsize',FS);
set(gca,'XTick',startDate:datenum(0,0,0,2,0,0):endDate);
xlabel('Time (UTC)');
datetick('x','HH:MM','keeplimits');
set(gca,'Fontsize',FS);
text(datenum(2020,04,01,11,05,0), 2000,'(c)' ,'Color', 'k','FontSize',20)

ax2=axes('position',ax.Position);
yyaxis left
ax2.YAxis(2).Color = c2;
ax2.YAxis(1).Color = c2;
ax2.XAxis.Color = c2;
plot(balloon_time,N_ice_tot.*1e3,'Color',c2,'LineStyle','-','LineWidth',LW);
ylabel('ICNC (L^{-1})');
ylim([1 200]);
set(gca,'YScale','log')
set(gca,'Fontsize',FS);
set(gca,'TickLength',[0.02 0.04],'TickDir','out');
ax2.Color='none';
set(gca,'XTick','')
xlim([startDate endDate]);
yyaxis right
ax2.Color='none';
set(gca,'YTick','')
sp3.Position=[0.1 0.11 0.7 0.26];
box on
set(gca, 'Layer', 'top')
end