function Figure9b(HOLIMOdata_path)
%HOLIMOdata_path -> path to HOLIMO data of the second flight on of 01
%April 2020 in 30sec resolution

strtdate='20200401121000';
enddate='20200401144000';
startDate = dtstr2dtnummx(cellstr(strtdate),'yyyyMMddHHmmss');
endDate = dtstr2dtnummx(cellstr(enddate),'yyyyMMddHHmmss');

%define constant
FS=26;
ice_small = 110e-6;

%% Holimo data reading
bar_aged_all=[];
bar_col_all=[];
bar_plate_all=[];

data_str={'200401_1'};
time_resolution='30';
holodata=readHoloBalloon([HOLIMOdata_path data_str{1} '_t' time_resolution '.nc']);

%Get balloon time and height
balloon_time = holodata.instData_timeGPS;


%Select time steps for plotting
idx=holodata.time >= datenum(strtdate,'yyyymmddHHMMSS') & balloon_time <= datenum(enddate,'yyyymmddHHMMSS');
balloon_time=balloon_time(idx);




%Ice selection and putting together classes
binSize = holodata.diameter;
binWidth = holodata.diameterLogBinWidth;
PSDlogNorm =holodata.Ice_Column_PSDlogNormMajsiz+holodata.Ice_Plate_PSDlogNormMajsiz+holodata.Ice_Small_PSDlogNormMajsiz;

idx_small = max(find(binSize<=ice_small));
N_ice = PSDlogNorm.*binWidth';
N_ice_small = nansum(N_ice(:,1:idx_small),2);
N_ice_small(N_ice_small==0)=NaN;

N_column=holodata.Ice_Column_concentration(idx);
N_small=holodata.Ice_Small_concentration(idx);
N_plate=holodata.Ice_Plate_concentration(idx);
N_Aged=holodata.Ice_Aged_concentration(idx)+holodata.Ice_Plate_aged_concentration(idx);
bar_col_all=N_column;
bar_aged_all=N_Aged;
bar_plate_all=N_plate+N_small;

%plot
fig = figure(1);
fig.Units = 'centimeters';
fig.Position = [0 1 52. 20.];
fig.PaperPositionMode = 'auto';
hold on
plot(balloon_time,N_ice_small(idx).*1e3,'Color',[0 0 0],'LineStyle','-','LineWidth',1.8);
ylabel('ICNC (L^{-1})');
bar_all=[ bar_plate_all,bar_col_all, bar_aged_all];
b=bar(balloon_time,bar_all.*1e3, 1, 'stacked','FaceColor','flat', 'EdgeColor','k');
b(2).CData=[0.1 0.5 1];
b(1).CData=[0.1 0.2 0.8];
b(3).CData=[1 0.7 0.3];
leg = legend(['ICNC_{pr<106 ' char(181) 'm}'],['Plate'],['Column'], ['Aged'],'Location','northeastoutside');
leg.ItemTokenSize = [10,20];
xlim([startDate endDate]);
set(gca,'Fontsize',FS);
set(gca,'XTick',startDate:datenum(0,0,0,1,0,0):endDate);
xlabel('Time (UTC)');
datetick('x','HH:MM','keeplimits');
box on
set(gca, 'SortMethod', 'depth')
end