function FigureA1(soundingdata_path,ceilodata_path)
%soundingdata_path -> path to all radiosonde data
%ceilodata_path -> path to all ceilometer data

datelong={'20191108','20191109','20191110','20191111','20191112','20200401'};


%constants for plotting
windbarspos=[2;1;0;5;5;-6];
subplotpos=[0.08; 0.23;0.38;0.53;0.68;0.83];
    
   

for m=1:length(datelong)
    date=datelong{m};
    start_date=[date '100000'];
    end_date=[date '160000'];  
    
    
    %get radiosonde data
    if strcmp(date, '20200401')
        output = import_soundings_NYA(soundingdata_path,[date(1:8) '17']);
    else
        output = import_soundings_NYA(soundingdata_path,[date(1:8) '11']);
    end

    
    radiosond_z=output.GeopHgt;
    radiosond_T=output.Temp;
    radiosond_wd=output.winddir;
    radiosond_ws=output.windspeed;
    radiosond_P=output.Pressure;
    
    %get ceilo data
    fid=fopen([ceilodata_path  'NYA_expanded_' start_date(1:4)  '-' start_date(5:6) '.tab']);

    fid=fopen(['/net/oxygen/holimo/3_Data/NyAlesund' start_date(1:4) '/16 - Ceilometer/NYA_expanded_' start_date(1:4)  '-' start_date(5:6) '.tab']);
    C = textscan(fid,' %s %u','HeaderLines',14); %{yyyy-mm-ddTHH:MM}D
    ceilo_time=C{1,1};
    cb=C{1,2};
    cb(cb==99999)=NaN;
    ceilo_time=datetime(ceilo_time,'InputFormat','yyyy-MM-dd''T''HH:mm');
    ceilo_t=datenum(ceilo_time);
    
    %Select time mean cloud base
    idx1= ceilo_t >= datenum(start_date,'yyyymmddHHMMSS') & ceilo_t <= datenum(end_date,'yyyymmddHHMMSS');
    ct1=ceilo_t(idx1);
    cb1=cb(idx1);
    couplingheight=mean(cb1)/2;    
    
    %Calculate potential temperature
    pottemp=radiosond_T.*(1000./radiosond_P).^(0.286);
    
    
     
    %Plot
    fig=figure(1);
    fig.Units = 'centimeters';
    fig.Position = [0 0 50.5 25.5];
    fig.PaperPositionMode = 'auto';
    sp=subplot(1,6,m);
    sp.Position=[subplotpos(m)    0.1100    0.12    0.8];
    
    %plot potential temperature for each day
    plot(pottemp(4:end)-273,radiosond_z(4:end), 'LineWidth', 3, 'color', 'b')
    hold on
    
    %plot cloud base height for each day
    title([date(1:4) '/'  date(5:6) '/'  date(7:8)])
    if strcmp(date, '20191108')
        text(-1.5,mean(cb1), '--- CB','Color', 'k','FontSize',20)
        xlim([-3 4])
    elseif strcmp(date, '20191109')
        text(-4.5,mean(cb1), '--- CB','Color', 'k','FontSize',20)
        xlim([-6 3])
    elseif strcmp(date, '20191110')
        text(-9.5,mean(cb1), '--- CB','Color', 'k','FontSize',20)
        xlim([-12 2])
    elseif strcmp(date, '20191111')
        text(-2,mean(cb1), '--- CB','Color', 'k','FontSize',20)
        xlim([-5 8])
    elseif strcmp(date, '20191112')
        text(-1,mean(cb1), '--- CB','Color', 'k','FontSize',20)
        xlim([-2 6])
    elseif strcmp(date, '20200401')
        text(-14,mean(cb1), '--- CB','Color', 'k','FontSize',20)
        xlim([-15 -5])
    end
    ylim([0 2000])
    if m==1
        ylabel('Altitude (m a.s.l.)')
    else
        set(gca,'YTick','')
    end
    if m==3
        xlabel('                             Potential Temperature (K)')
    end
    set(gca,'Fontsize',22);
    
    %plot wind barbs from radiosonde for each day
    u = -(abs(radiosond_ws)).*sind(radiosond_wd).*0.514444;
    v = -(abs(radiosond_ws)).*cosd(radiosond_wd).*0.514444;
    speed_lims.min = 0;
    speed_lims.max = 1;
    x = transpose(repelem(windbarspos(m),length(u)));
    y = radiosond_z;
    idx = 1:20:length(u);
    u = u(idx);
    v = v(idx);
    x = x(idx);
    y = y(idx);
    windbarbs(u,v,x,y,1,[],2,speed_lims,'k');
end
end
